.. nadzoring documentation master file

Welcome to Nadzoring's documentation!
======================================

**Nadzoring** (from Russian "надзор" - supervision/oversight + English "-ing" suffix)
is a FOSS (Free and Open Source Software) command-line tool for detecting website blocks,
monitoring service availability, and network analysis.

.. note::
   This documentation is for version |version|.

Versions
--------

.. list-table::
   :header-rows: 1
   :widths: 20 60 20

   * - Version
     - Description
     - Status
   * - `main </nadzoring/main/>`_
     - Latest development version from the main branch
     - **Latest**
   * - `v0.1.9 </nadzoring/v0.1.9/>`_
     - Stable release — add more commands, add asyncio support, improve codestyle and python API
     - Stable
   * - `v0.1.8 </nadzoring/v0.1.8/>`_
     - Stable release — fix issues and bugs and improve project API
     - Stable
   * - `v0.1.7 </nadzoring/v0.1.7/>`_
     - Stable release — add security command group and improve library API
     - Stable
   * - `v0.1.6 </nadzoring/v0.1.6/>`_
     - Stable release — refactor core modules, improve library-mode
     - Stable
   * - `v0.1.5 </nadzoring/v0.1.5/>`_
     - Stable release — small code API redesigning, typing improvements, UX improved
     - Stable
   * - `v0.1.4 </nadzoring/v0.1.4/>`_
     - Stable release — improved network base, arp commands
     - Stable
   * - `v0.1.3 </nadzoring/v0.1.3/>`_
     - Stable release — DNS lookup, network base, utils, commands
     - Stable
   * - `v0.1.2 </nadzoring/v0.1.2/>`_
     - Added DNS lookup and commands modules
     - Stable
   * - `v0.1.1 </nadzoring/v0.1.1/>`_
     - Initial public release with network base
     - Stable

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   source/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
